---
title: <span class="badge object-type-scalar"></span> Kibibytes
---
# <span class="badge object-type-scalar"></span> Kibibytes

Data: kibibytes

## Definition

```python
# Data: kibibytes
Kibibytes: typing.Literal["kbytes"] = "kbytes"
```
